<?php
/**
 * WooCommerce Template Functions.
 *
 * @package activatelife
 */

if ( ! function_exists( 'activatelife_before_content' ) ) {
	/**
	 * Before Content
	 * Wraps all WooCommerce content in wrappers which match the theme markup
	 *
	 * @since   1.0.0
	 * @return  void
	 */
	function activatelife_before_content() {
		?>
		<div id="primary" class="content-area">
			<main id="main" class="site-main" role="main">
		<?php
	}
}

if ( ! function_exists( 'activatelife_after_content' ) ) {
	/**
	 * After Content
	 * Closes the wrapping divs
	 *
	 * @since   1.0.0
	 * @return  void
	 */
	function activatelife_after_content() {
		?>
			</main><!-- #main -->
		</div><!-- #primary -->

		<?php

		/**
		 * Functions hooked in to activatelife_sidebar action
		 *
		 * @see activatelife_get_sidebar      - 10
		 */

		do_action( 'activatelife_sidebar' );
	}
}

if ( ! function_exists( 'activatelife_cart_link_fragment' ) ) {
	/**
	 * Cart Fragments
	 * Ensure cart contents update when products are added to the cart via AJAX
	 *
	 * @param  array $fragments Fragments to refresh via AJAX.
	 * @return array            Fragments to refresh via AJAX
	 */
	function activatelife_cart_link_fragment( $fragments ) {
		global $woocommerce;

		ob_start();
		activatelife_cart_link();
		$fragments['a.cart-contents'] = ob_get_clean();

		ob_start();
		activatelife_handheld_footer_bar_cart_link();
		$fragments['a.footer-cart-contents'] = ob_get_clean();

		return $fragments;
	}
}

if ( ! function_exists( 'activatelife_cart_link' ) ) {
	/**
	 * Cart Link
	 * Displayed a link to the cart including the number of items present and the cart total
	 *
	 * @return void
	 * @since  1.0.0
	 */
	function activatelife_cart_link() {
		?>
			<a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'activatelife' ); ?>">
				<?php /* translators: %d: number of items in cart */ ?>
				<?php echo wp_kses_post( WC()->cart->get_cart_subtotal() ); ?> <span class="count"><?php echo wp_kses_data( sprintf( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(), 'activatelife' ), WC()->cart->get_cart_contents_count() ) ); ?></span>
			</a>
		<?php
	}
}

if ( ! function_exists( 'activatelife_product_search' ) ) {
	/**
	 * Display Product Search
	 *
	 * @since  1.0.0
	 * @uses  activatelife_is_woocommerce_activated() check if WooCommerce is activated
	 * @return void
	 */
	function activatelife_product_search() {
		if ( activatelife_is_woocommerce_activated() ) {
			?>
			<div class="site-search">
				<?php the_widget( 'WC_Widget_Product_Search', 'title=' ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'activatelife_header_cart' ) ) {
	/**
	 * Display Header Cart
	 *
	 * @since  1.0.0
	 * @uses  activatelife_is_woocommerce_activated() check if WooCommerce is activated
	 * @return void
	 */
	function activatelife_header_cart() {
		if ( activatelife_is_woocommerce_activated() ) {
			if ( is_cart() ) {
				$class = 'current-menu-item';
			} else {
				$class = '';
			}
			?>
		<ul id="site-header-cart" class="site-header-cart menu">
			<li class="<?php echo esc_attr( $class ); ?>">
				<?php activatelife_cart_link(); ?>
			</li>
			<li>
				<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
			</li>
		</ul>
			<?php
		}
	}
}

/**
 * Generate a WooCommerce cart link
 *
 * @return void
 */
function activatelife_woocommerce_cart_link() {

	if ( ! class_exists( 'WooCommerce' )) {
		return;
	}

	add_action( 'wp_footer', 'woocommerce_slideout_cart' );

	ob_start();
	load_inline_svg( 'bag.svg' );
	$icon = ob_get_clean();

	global $woocommerce;

	/**
	 * Filters the cart menu item URL.
	 *
	 * @since 1.2.0
	 *
	 * @param string URL to the WooCommerce cart page.
	 */
	$cart_url = (string) apply_filters( 'go_menu_cart_url', wc_get_cart_url() );

	/**
	 * Filters the cart menu item alt text.
	 *
	 * @since 1.2.0
	 *
	 * @param string Alt text for the cart menu item.
	 */
	$cart_alt_text = (string) apply_filters( 'go_menu_cart_alt', __( 'View cart', 'activatelife' ) );

	/**
	 * Filters the cart menu item text.
	 *
	 * @since 1.2.0
	 *
	 * @param string Text for the cart menu item.
	 */
	$cart_text = (string) apply_filters(
		'go_menu_cart_text',
		sprintf(
			'%1$s <span class="item-count">%2$d</span>',
			$icon,
			$woocommerce->cart->get_cart_contents_count()
		)
	);

	if ( empty( $cart_text ) ) {

		$cart_text = sprintf(
			'%1$s %2$d',
			$icon,
			$woocommerce->cart->get_cart_contents_count()
		);

	}

	$element_wrap = 'button';

	printf(
		'<%1$s id="header__cart-toggle"%2$sclass="header__cart-toggle" alt="%3$s">%4$s</%1$s>',
		esc_html( $element_wrap ),
		( 'a' === $element_wrap ) ? ' href="' . esc_url( $cart_url ) . '" ' : ' ',
		esc_attr( $cart_alt_text ),
		$cart_text // @codingStandardsIgnoreLine
	);

}

/**
 * Render the markup for yhe WooCommerce slideout cart
 *
 * @return mixed Markup for the slideout cart.
 */
function woocommerce_slideout_cart() {

	global $woocommerce;

	$cart_count = $woocommerce->cart->get_cart_contents_count();

	?>

	<div id="site-overlay" class="site-overlay"></div>

	<div id="site-nav--cart" class="site-nav style--sidebar show-cart">

		<div id="site-cart" class="site-nav-container" tabindex="-1">

			<button id="site-close-handle" class="site-close-handle" aria-label="<?php esc_attr_e( 'Close sidebar', 'activatelife' ); ?>" title="<?php esc_attr_e( 'Close sidebar', 'activatelife' ); ?>">
				<?php load_inline_svg( 'close.svg' ); ?>
			</button>

			<div class="site-nav-container-last">

				<div class="site-cart-heading">

					<h6 class="title"><?php esc_html_e( 'Cart', 'activatelife' ); ?></h6>

					<p class="subheading">
						<?php
						printf(
							esc_html(
							/* translators: 1. Single integer value. (eg: 1 product in your cart). 2. Integer larger than 1. (eg: 5 products in your cart). */
								_n( '%s product in your cart', '%s products in your cart', $cart_count, 'activatelife' )
							),
							esc_html( number_format_i18n( $cart_count ) )
						);
						?>
					</p>

				</div>

				<?php the_widget( 'WC_Widget_Cart', array(), array( 'before_title' => '<h2 class="widgettitle screen-reader-text"">' ) ); ?>

			</div>

		</div>

	</div>

	<?php
}

if ( ! function_exists( 'activatelife_upsell_display' ) ) {
	/**
	 * Upsells
	 * Replace the default upsell function with our own which displays the correct number product columns
	 *
	 * @since   1.0.0
	 * @return  void
	 * @uses    woocommerce_upsell_display()
	 */
	function activatelife_upsell_display() {
		$columns = apply_filters( 'activatelife_upsells_columns', 3 );
		woocommerce_upsell_display( -1, $columns );
	}
}

if ( ! function_exists( 'activatelife_sorting_wrapper' ) ) {
	/**
	 * Sorting wrapper
	 *
	 * @since   1.4.3
	 * @return  void
	 */
	function activatelife_sorting_wrapper() {
		echo '<div class="activatelife-sorting">';
	}
}

if ( ! function_exists( 'activatelife_sorting_wrapper_close' ) ) {
	/**
	 * Sorting wrapper close
	 *
	 * @since   1.4.3
	 * @return  void
	 */
	function activatelife_sorting_wrapper_close() {
		echo '</div>';
	}
}

if ( ! function_exists( 'activatelife_product_columns_wrapper' ) ) {
	/**
	 * Product columns wrapper
	 *
	 * @since   2.2.0
	 * @return  void
	 */
	function activatelife_product_columns_wrapper() {
		$columns = activatelife_loop_columns();
		echo '<div class="columns-' . absint( $columns ) . '">';
	}
}

if ( ! function_exists( 'activatelife_loop_columns' ) ) {
	/**
	 * Default loop columns on product archives
	 *
	 * @return integer products per row
	 * @since  1.0.0
	 */
	function activatelife_loop_columns() {
		$columns = 3; // 3 products per row

		if ( function_exists( 'wc_get_default_products_per_row' ) ) {
			$columns = wc_get_default_products_per_row();
		}

		return apply_filters( 'activatelife_loop_columns', $columns );
	}
}

if ( ! function_exists( 'activatelife_product_columns_wrapper_close' ) ) {
	/**
	 * Product columns wrapper close
	 *
	 * @since   2.2.0
	 * @return  void
	 */
	function activatelife_product_columns_wrapper_close() {
		echo '</div>';
	}
}

if ( ! function_exists( 'activatelife_shop_messages' ) ) {
	/**
	 * Activatelife shop messages
	 *
	 * @since   1.4.4
	 * @uses    activatelife_do_shortcode
	 */
	function activatelife_shop_messages() {
		if ( ! is_checkout() ) {
			echo wp_kses_post( activatelife_do_shortcode( 'woocommerce_messages' ) );
		}
	}
}

if ( ! function_exists( 'activatelife_woocommerce_pagination' ) ) {
	/**
	 * Activatelife WooCommerce Pagination
	 * WooCommerce disables the product pagination inside the woocommerce_product_subcategories() function
	 * but since Activatelife adds pagination before that function is excuted we need a separate function to
	 * determine whether or not to display the pagination.
	 *
	 * @since 1.4.4
	 */
	function activatelife_woocommerce_pagination() {
		if ( woocommerce_products_will_display() ) {
			woocommerce_pagination();
		}
	}
}

if ( ! function_exists( 'activatelife_product_categories' ) ) {
	/**
	 * Display Product Categories
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @param array $args the product section args.
	 * @return void
	 */
	function activatelife_product_categories( $args ) {
		$args = apply_filters(
			'activatelife_product_categories_args', array(
				'limit'            => 3,
				'columns'          => 3,
				'child_categories' => 0,
				'orderby'          => 'menu_order',
				'title'            => __( 'Shop by Category', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'product_categories', apply_filters(
				'activatelife_product_categories_shortcode_args', array(
					'number'  => intval( $args['limit'] ),
					'columns' => intval( $args['columns'] ),
					'orderby' => esc_attr( $args['orderby'] ),
					'parent'  => esc_attr( $args['child_categories'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns product categories
		 */
		if ( false !== strpos( $shortcode_content, 'product-category' ) ) {
			echo '<section class="activatelife-product-section activatelife-product-categories" aria-label="' . esc_attr__( 'Product Categories', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_product_categories' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_product_categories_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_product_categories' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_recent_products' ) ) {
	/**
	 * Display Recent Products
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @param array $args the product section args.
	 * @return void
	 */
	function activatelife_recent_products( $args ) {
		$args = apply_filters(
			'activatelife_recent_products_args', array(
				'limit'   => 4,
				'columns' => 4,
				'orderby' => 'date',
				'order'   => 'desc',
				'title'   => __( 'New In', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'products', apply_filters(
				'activatelife_recent_products_shortcode_args', array(
					'orderby'  => esc_attr( $args['orderby'] ),
					'order'    => esc_attr( $args['order'] ),
					'per_page' => intval( $args['limit'] ),
					'columns'  => intval( $args['columns'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns products
		 */
		if ( false !== strpos( $shortcode_content, 'product' ) ) {
			echo '<section class="activatelife-product-section activatelife-recent-products" aria-label="' . esc_attr__( 'Recent Products', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_recent_products' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_recent_products_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_recent_products' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_featured_products' ) ) {
	/**
	 * Display Featured Products
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @param array $args the product section args.
	 * @return void
	 */
	function activatelife_featured_products( $args ) {
		$args = apply_filters(
			'activatelife_featured_products_args', array(
				'limit'      => 4,
				'columns'    => 4,
				'orderby'    => 'date',
				'order'      => 'desc',
				'visibility' => 'featured',
				'title'      => __( 'We Recommend', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'products', apply_filters(
				'activatelife_featured_products_shortcode_args', array(
					'per_page'   => intval( $args['limit'] ),
					'columns'    => intval( $args['columns'] ),
					'orderby'    => esc_attr( $args['orderby'] ),
					'order'      => esc_attr( $args['order'] ),
					'visibility' => esc_attr( $args['visibility'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns products
		 */
		if ( false !== strpos( $shortcode_content, 'product' ) ) {
			echo '<section class="activatelife-product-section activatelife-featured-products" aria-label="' . esc_attr__( 'Featured Products', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_featured_products' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_featured_products_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_featured_products' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_popular_products' ) ) {
	/**
	 * Display Popular Products
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @param array $args the product section args.
	 * @return void
	 */
	function activatelife_popular_products( $args ) {
		$args = apply_filters(
			'activatelife_popular_products_args', array(
				'limit'   => 4,
				'columns' => 4,
				'orderby' => 'rating',
				'order'   => 'desc',
				'title'   => __( 'Fan Favorites', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'products', apply_filters(
				'activatelife_popular_products_shortcode_args', array(
					'per_page' => intval( $args['limit'] ),
					'columns'  => intval( $args['columns'] ),
					'orderby'  => esc_attr( $args['orderby'] ),
					'order'    => esc_attr( $args['order'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns products
		 */
		if ( false !== strpos( $shortcode_content, 'product' ) ) {
			echo '<section class="activatelife-product-section activatelife-popular-products" aria-label="' . esc_attr__( 'Popular Products', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_popular_products' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_popular_products_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_popular_products' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_on_sale_products' ) ) {
	/**
	 * Display On Sale Products
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @param array $args the product section args.
	 * @since  1.0.0
	 * @return void
	 */
	function activatelife_on_sale_products( $args ) {
		$args = apply_filters(
			'activatelife_on_sale_products_args', array(
				'limit'   => 4,
				'columns' => 4,
				'orderby' => 'date',
				'order'   => 'desc',
				'on_sale' => 'true',
				'title'   => __( 'On Sale', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'products', apply_filters(
				'activatelife_on_sale_products_shortcode_args', array(
					'per_page' => intval( $args['limit'] ),
					'columns'  => intval( $args['columns'] ),
					'orderby'  => esc_attr( $args['orderby'] ),
					'order'    => esc_attr( $args['order'] ),
					'on_sale'  => esc_attr( $args['on_sale'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns products
		 */
		if ( false !== strpos( $shortcode_content, 'product' ) ) {
			echo '<section class="activatelife-product-section activatelife-on-sale-products" aria-label="' . esc_attr__( 'On Sale Products', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_on_sale_products' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_on_sale_products_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_on_sale_products' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_best_selling_products' ) ) {
	/**
	 * Display Best Selling Products
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since 2.0.0
	 * @param array $args the product section args.
	 * @return void
	 */
	function activatelife_best_selling_products( $args ) {
		$args = apply_filters(
			'activatelife_best_selling_products_args', array(
				'limit'   => 4,
				'columns' => 4,
				'orderby' => 'popularity',
				'order'   => 'desc',
				'title'   => esc_attr__( 'Best Sellers', 'activatelife' ),
			)
		);

		$shortcode_content = activatelife_do_shortcode(
			'products', apply_filters(
				'activatelife_best_selling_products_shortcode_args', array(
					'per_page' => intval( $args['limit'] ),
					'columns'  => intval( $args['columns'] ),
					'orderby'  => esc_attr( $args['orderby'] ),
					'order'    => esc_attr( $args['order'] ),
				)
			)
		);

		/**
		 * Only display the section if the shortcode returns products
		 */
		if ( false !== strpos( $shortcode_content, 'product' ) ) {
			echo '<section class="activatelife-product-section activatelife-best-selling-products" aria-label="' . esc_attr__( 'Best Selling Products', 'activatelife' ) . '">';

			do_action( 'activatelife_homepage_before_best_selling_products' );

			echo '<h2 class="section-title">' . wp_kses_post( $args['title'] ) . '</h2>';

			do_action( 'activatelife_homepage_after_best_selling_products_title' );

			echo $shortcode_content; // WPCS: XSS ok.

			do_action( 'activatelife_homepage_after_best_selling_products' );

			echo '</section>';
		}
	}
}

if ( ! function_exists( 'activatelife_promoted_products' ) ) {
	/**
	 * Featured and On-Sale Products
	 * Check for featured products then on-sale products and use the appropiate shortcode.
	 * If neither exist, it can fallback to show recently added products.
	 *
	 * @since  1.5.1
	 * @param integer $per_page total products to display.
	 * @param integer $columns columns to arrange products in to.
	 * @param boolean $recent_fallback Should the function display recent products as a fallback when there are no featured or on-sale products?.
	 * @uses  activatelife_is_woocommerce_activated()
	 * @uses  wc_get_featured_product_ids()
	 * @uses  wc_get_product_ids_on_sale()
	 * @uses  activatelife_do_shortcode()
	 * @return void
	 */
	function activatelife_promoted_products( $per_page = '2', $columns = '2', $recent_fallback = true ) {
		if ( activatelife_is_woocommerce_activated() ) {

			if ( wc_get_featured_product_ids() ) {

				echo '<h2>' . esc_html__( 'Featured Products', 'activatelife' ) . '</h2>';

				echo activatelife_do_shortcode(
					'featured_products', array(
						'per_page' => $per_page,
						'columns'  => $columns,
					)
				); // WPCS: XSS ok.
			} elseif ( wc_get_product_ids_on_sale() ) {

				echo '<h2>' . esc_html__( 'On Sale Now', 'activatelife' ) . '</h2>';

				echo activatelife_do_shortcode(
					'sale_products', array(
						'per_page' => $per_page,
						'columns'  => $columns,
					)
				); // WPCS: XSS ok.
			} elseif ( $recent_fallback ) {

				echo '<h2>' . esc_html__( 'New In Store', 'activatelife' ) . '</h2>';

				echo activatelife_do_shortcode(
					'recent_products', array(
						'per_page' => $per_page,
						'columns'  => $columns,
					)
				); // WPCS: XSS ok.
			}
		}
	}
}

if ( ! function_exists( 'activatelife_handheld_footer_bar' ) ) {
	/**
	 * Display a menu intended for use on handheld devices
	 *
	 * @since 2.0.0
	 */
	function activatelife_handheld_footer_bar() {
		$links = array(
			'my-account' => array(
				'priority' => 10,
				'callback' => 'activatelife_handheld_footer_bar_account_link',
			),
			'search'     => array(
				'priority' => 20,
				'callback' => 'activatelife_handheld_footer_bar_search',
			),
			'cart'       => array(
				'priority' => 30,
				'callback' => 'activatelife_handheld_footer_bar_cart_link',
			),
		);

		if ( wc_get_page_id( 'myaccount' ) === -1 ) {
			unset( $links['my-account'] );
		}

		if ( wc_get_page_id( 'cart' ) === -1 ) {
			unset( $links['cart'] );
		}

		$links = apply_filters( 'activatelife_handheld_footer_bar_links', $links );
		?>
		<div class="activatelife-handheld-footer-bar">
			<ul class="columns-<?php echo count( $links ); ?>">
				<?php foreach ( $links as $key => $link ) : ?>
					<li class="<?php echo esc_attr( $key ); ?>">
						<?php
						if ( $link['callback'] ) {
							call_user_func( $link['callback'], $key, $link );
						}
						?>
					</li>
				<?php endforeach; ?>
			</ul>
		</div>
		<?php
	}
}

if ( ! function_exists( 'activatelife_handheld_footer_bar_search' ) ) {
	/**
	 * The search callback function for the handheld footer bar
	 *
	 * @since 2.0.0
	 */
	function activatelife_handheld_footer_bar_search() {
		echo '<a href="">' . esc_attr__( 'Search', 'activatelife' ) . '</a>';
		activatelife_product_search();
	}
}

if ( ! function_exists( 'activatelife_handheld_footer_bar_cart_link' ) ) {
	/**
	 * The cart callback function for the handheld footer bar
	 *
	 * @since 2.0.0
	 */
	function activatelife_handheld_footer_bar_cart_link() {
		?>
			<a class="footer-cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'activatelife' ); ?>">
				<span class="count"><?php echo wp_kses_data( WC()->cart->get_cart_contents_count() ); ?></span>
			</a>
		<?php
	}
}

if ( ! function_exists( 'activatelife_handheld_footer_bar_account_link' ) ) {
	/**
	 * The account callback function for the handheld footer bar
	 *
	 * @since 2.0.0
	 */
	function activatelife_handheld_footer_bar_account_link() {
		echo '<a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '">' . esc_attr__( 'My Account', 'activatelife' ) . '</a>';
	}
}

if ( ! function_exists( 'activatelife_single_product_pagination' ) ) {
	/**
	 * Single Product Pagination
	 *
	 * @since 2.3.0
	 */
	function activatelife_single_product_pagination() {
		if ( class_exists( 'Activatelife_Product_Pagination' ) || true !== get_theme_mod( 'activatelife_product_pagination' ) ) {
			return;
		}

		// Show only products in the same category?
		$in_same_term   = apply_filters( 'activatelife_single_product_pagination_same_category', true );
		$excluded_terms = apply_filters( 'activatelife_single_product_pagination_excluded_terms', '' );
		$taxonomy       = apply_filters( 'activatelife_single_product_pagination_taxonomy', 'product_cat' );

		$previous_product = activatelife_get_previous_product( $in_same_term, $excluded_terms, $taxonomy );
		$next_product     = activatelife_get_next_product( $in_same_term, $excluded_terms, $taxonomy );

		if ( ! $previous_product && ! $next_product ) {
			return;
		}

		?>
		<nav class="activatelife-product-pagination" aria-label="<?php esc_attr_e( 'More products', 'activatelife' ); ?>">
			<?php if ( $previous_product ) : ?>
				<a href="<?php echo esc_url( $previous_product->get_permalink() ); ?>" rel="prev">
					<?php echo wp_kses_post( $previous_product->get_image() ); ?>
					<span class="activatelife-product-pagination__title"><?php echo wp_kses_post( $previous_product->get_name() ); ?></span>
				</a>
			<?php endif; ?>

			<?php if ( $next_product ) : ?>
				<a href="<?php echo esc_url( $next_product->get_permalink() ); ?>" rel="next">
					<?php echo wp_kses_post( $next_product->get_image() ); ?>
					<span class="activatelife-product-pagination__title"><?php echo wp_kses_post( $next_product->get_name() ); ?></span>
				</a>
			<?php endif; ?>
		</nav><!-- .activatelife-product-pagination -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_sticky_single_add_to_cart' ) ) {
	/**
	 * Sticky Add to Cart
	 *
	 * @since 2.3.0
	 */
	function activatelife_sticky_single_add_to_cart() {
		global $product;

		if ( class_exists( 'Activatelife_Sticky_Add_to_Cart' ) || true !== get_theme_mod( 'activatelife_sticky_add_to_cart' ) ) {
			return;
		}

		if ( ! is_product() ) {
			return;
		}

		$show = false;

		if ( $product->is_purchasable() && $product->is_in_stock() ) {
			$show = true;
		} else if ( $product->is_type( 'external' ) ) {
			$show = true;
		}

		if ( ! $show ) {
			return;
		}

		$params = apply_filters(
			'activatelife_sticky_add_to_cart_params', array(
				'trigger_class' => 'entry-summary',
			)
		);

		wp_localize_script( 'activatelife-sticky-add-to-cart', 'activatelife_sticky_add_to_cart_params', $params );

		wp_enqueue_script( 'activatelife-sticky-add-to-cart' );
		?>
			<section class="activatelife-sticky-add-to-cart">
				<div class="col-full">
					<div class="activatelife-sticky-add-to-cart__content">
						<?php echo wp_kses_post( woocommerce_get_product_thumbnail() ); ?>
						<div class="activatelife-sticky-add-to-cart__content-product-info">
							<span class="activatelife-sticky-add-to-cart__content-title"><?php esc_attr_e( 'You\'re viewing:', 'activatelife' ); ?> <strong><?php the_title(); ?></strong></span>
							<span class="activatelife-sticky-add-to-cart__content-price"><?php echo wp_kses_post( $product->get_price_html() ); ?></span>
							<?php echo wp_kses_post( wc_get_rating_html( $product->get_average_rating() ) ); ?>
						</div>
						<a href="<?php echo esc_url( $product->add_to_cart_url() ); ?>" class="activatelife-sticky-add-to-cart__content-button button alt" rel="nofollow">
							<?php echo esc_attr( $product->add_to_cart_text() ); ?>
						</a>
					</div>
				</div>
			</section><!-- .activatelife-sticky-add-to-cart -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_woocommerce_product_loop_wishlist_button' ) ) {
	function activatelife_woocommerce_product_loop_wishlist_button() {
		if ( activatelife_is_extension_activated( 'YITH_WCWL' ) ) {
			echo activatelife_do_shortcode( 'yith_wcwl_add_to_wishlist' );
		}
	}
}

if ( ! function_exists( 'activatelife_woocommerce_product_loop_compare_button' ) ) {
	function activatelife_woocommerce_product_loop_compare_button() {
		if ( activatelife_is_extension_activated( 'YITH_Woocompare' ) ) {
			global $yith_woocompare;
			if ( get_option( 'yith_woocompare_compare_button_in_products_list', 'no' ) == 'yes' ) {
				remove_action( 'woocommerce_after_shop_loop_item', array(
					$yith_woocompare->obj,
					'add_compare_link'
				), 20 );
			}

			echo activatelife_do_shortcode( 'yith_compare_button' );
		}
	}
}
